@@ -463,6 +463,8 @@ gtkTextBuffer <- gtkTextBufferNew
 
 gtkTextChildAnchor <- gtkTextChildAnchorNew
 
+gtkTextMark <- gtkTextMarkNew
+
 gtkTextTag <- gtkTextTagNew
 
 gtkTextTagTable <- gtkTextTagTableNew
@@ -503,6 +505,8 @@ gtkToolItem <- gtkToolItemNew
 
 gtkTooltips <- gtkTooltipsNew
 
+gtkTreeModelFilter <- gtkTreeModelFilterNew
+
 gtkTreeModelSort <- gtkTreeModelSortNewWithModel
 
 gtkTreeStore <-
@@ -597,3 +601,11 @@ gtkRecentChooserDialog <- gtkRecentChooserDialogNew
 
 gtkAssistant <- gtkAssistantNew
 
+gtkBuilder <- gtkBuilderNew
+
+gtkRecentAction <- gtkRecentActionNew
+
+gtkScaleButton <- gtkScaleButtonNew
+
+gtkVolumeButton <- gtkVolumeButtonNew
+
